==> dadata-suggestions-1.1.0.tgz: package/README.md <==
[![npm version](https://badge.fury.io/js/dadata-suggestions.svg)](https://badge.fury.io/js/dadata-suggestions)
# [Dadata.ru](https://dadata.ru/api/suggest/) suggestions package

### Dev dependencies
* jsdoc-to-markdown
* pre-commit

# Installation
`$ npm i dadata-suggestions`

# Usage
```
const Dadata = require('dadata-suggestions');
const dadata = new Dadata(API_KEY);
dadata.address('Невский', 30)
    .then((data) => {
        console.log(data);
    })
    .catch(console.error);
```

# [API](https://github.com/mike1pol/dadata-suggestions/blob/master/API.md)

# License

The MIT License (MIT)

Copyright (c) 2016 Mikhail Poluboyarinov

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> dadata-suggestions-1.1.1.tgz: package/README.md <==
[![npm version](https://badge.fury.io/js/dadata-suggestions.svg)](https://badge.fury.io/js/dadata-suggestions)
# [Dadata.ru](https://dadata.ru/api/suggest/) suggestions package

### Dev dependencies
* jsdoc-to-markdown
* pre-commit

# Installation
`$ npm i dadata-suggestions`

# Usage
```
const Dadata = require('dadata-suggestions');
const dadata = new Dadata(API_KEY);
dadata.address({ query: 'Невский', count: 5 })
    .then((data) => {
        console.log(data);
    })
    .catch(console.error);
```

# [API](https://github.com/mike1pol/dadata-suggestions/blob/master/API.md)

# License

The MIT License (MIT)

Copyright (c) 2016 Mikhail Poluboyarinov

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
